==> googleway_1.0.0.tar.gz: googleway/tests/testthat/test-google_distances.R <==
 context("Google distance")

## api keys are not included in the package
## and so can't be tested
skip_api_key <- function() {
  skip("key not available")
}

test_that("google_distance returns data.frame", {
  ## skip this test
  skip_api_key()

  df <- google_distance(origins = c(-37.8179746, 144.9668636),
                          destinations = c(-37.81659, 144.9841),
                          mode = "walking",
                          key = key,
                          simplify = TRUE)

  expect_equal(class(df), "list")
  expect_equal(names(df), c("geocoded_waypoints","routes","status"))
  expect_equal(length(df[[1]]), 3)
})



test_that("origins are lat/lon", {

  expect_error(google_distance(origins = list(c(144.9668636)),
                               destinations = c(-37.81659, 144.9841),
                               mode = "driving",
                               key = "abc"),
               "Origins elements must be either a numeric vector of lat/lon coordinates, or an address string")

})

test_that("Destinations are lat/lon", {

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                               destinations = c(-37.81659),
                               mode = "driving",
                               key = "abc"),
               "Destinations elements must be either a numeric vector of lat/lon coordinates, or an address string")

})

test_that("Avoid is a valid type", {

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                                 destinations = list(c(-37.81659, 144.9841)),
                                 avoid = "dont avoid",
                                 key = "abc",
                                 simplify = TRUE),
               "avoid must be one of tolls, highways, ferries or indoor")
})

test_that("Departure time is not in the past",{

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                               destinations = list(c(-37.81659, 144.9841)),
                                 departure_time = as.POSIXct("2015-01-01"),
                                 key = "abc",
                                 simplify = TRUE),
               "departure_time must not be in the past")

})

test_that("waypoints only valid for certain modes",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 waypoints = list(c(-37.81659, 144.9841),
                                                  "Ringwood, Victoria"),
                                 mode = "transit",
                                 key = "abc"),
               "waypoints are only valid for driving, walking or bicycling modes")
})

test_that("waypoints are a list",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 waypoints = c(-37.81659, 144.9841),
                                 key = "abc"),
               "waypoints must be a list")
})

test_that("map url is a single string",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 alternatives = c(FALSE, TRUE),
                                 key = "abc"),
               "invalid map_url")
})


test_that("transit_mode issues warning when mode != transit",{

  skip_api_key()

  expect_warning(google_distance(origins = "Melbourne Airport, Australia",
                                   destinations = "Portsea, Melbourne, Australia",
                                   departure_time = Sys.time() + (24 * 60 * 60),
                                   waypoints = list(via = c(-37.81659, 144.9841),
                                                    via = "Ringwood, Victoria"),
                                   transit_mode = "bus",
                                   key = "abc"),
                 "You have specified a transit_mode, but are not using mode = 'transit'. Therefore this argument will be ignored")

})


test_that("warning when both arrival and departure times supplied", {

  skip_api_key()

  expect_warning(google_distance(origins = "Melbourne Airport, Australia",
                                   destinations = "Portsea, Melbourne, Australia",
                                   departure_time = Sys.time() + (24 * 60 * 60),
                                   arrival_time = Sys.time() + (24 * 60 * 60),
                                   key = "abc"),
                 "you have supplied both an arrival_time and a departure_time - only one is allowed. The arrival_time will be ignored")

})

==> googleway_2.0.0.tar.gz: googleway/tests/testthat/test-google_distances.R <==
context("Google distance")

# test_that("google_distance returns data.frame", {
#
#   skip_on_cran()
#   skip_on_travis()
#   key <- read.dcf("~/Documents/.googleAPI", fields = c("GOOGLE_API_KEY"))
#
#   df <- google_distance(origins = list(c(-37.8179746, 144.9668636)),
#                         destinations = list(c(-37.81659, 144.9841)),
#                         mode = "walking",
#                         key = key,
#                         simplify = TRUE)
#
#   expect_equal(class(df), "list")
#   expect_equal(names(df), c("destination_addresses","origin_addresses","rows","status"))
# })
#

test_that("origins are lat/lon", {

  expect_error(google_distance(origins = list(c(144.9668636)),
                               destinations = c(-37.81659, 144.9841),
                               mode = "driving",
                               key = "abc"),
               "Origins elements must be either a numeric vector of lat/lon coordinates, or an address string")

})

test_that("Destinations are lat/lon", {

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                               destinations = c(-37.81659),
                               mode = "driving",
                               key = "abc"),
               "Destinations elements must be either a numeric vector of lat/lon coordinates, or an address string")

})

test_that("Avoid is a valid type", {

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                                 destinations = list(c(-37.81659, 144.9841)),
                                 avoid = "dont avoid",
                                 key = "abc",
                                 simplify = TRUE),
               "avoid can only include tolls, highways, ferries or indoor")
})

test_that("Departure time is not in the past",{

  expect_error(google_distance(origins = list(c(-37.8179746, 144.9668636)),
                               destinations = list(c(-37.81659, 144.9841)),
                                 departure_time = as.POSIXct("2015-01-01"),
                                 key = "abc",
                                 simplify = TRUE),
               "departure_time must not be in the past")

})

test_that("waypoints only valid for certain modes",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 waypoints = list(c(-37.81659, 144.9841),
                                                  "Ringwood, Victoria"),
                                 mode = "transit",
                                 key = "abc"),
               "waypoints are only valid for driving, walking or bicycling modes")
})

test_that("waypoints are a list",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 waypoints = c(-37.81659, 144.9841),
                                 key = "abc"),
               "waypoints must be a list")
})

test_that("alternatives either TRUE or FALSE",{

  expect_error(google_distance(origins = "Melbourne Airport",
                                 destinations = "Sorrento",
                                 alternatives = c(FALSE, TRUE),
                                 key = "abc"))
})

test_that("transit_mode issues warning when mode != transit",{

  expect_warning(google_distance(origins = "Melbourne Airport, Australia",
                                   destinations = "Portsea, Melbourne, Australia",
                                   departure_time = Sys.time() + (24 * 60 * 60),
                                   waypoints = list(via = c(-37.81659, 144.9841),
                                                    via = "Ringwood, Victoria"),
                                   transit_mode = "bus",
                                   key = "abc"),
                 "You have specified a transit_mode, but are not using mode = 'transit'. Therefore this argument will be ignored")

})

test_that("warning when both arrival and departure times supplied", {

  expect_warning(google_distance(origins = "Melbourne Airport, Australia",
                                   destinations = "Portsea, Melbourne, Australia",
                                   departure_time = Sys.time() + (24 * 60 * 60),
                                   arrival_time = Sys.time() + (24 * 60 * 60),
                                   key = "abc"),
                 "you have supplied both an arrival_time and a departure_time - only one is allowed. The arrival_time will be ignored")

})
